diff --git a/tests/TestSuite_pvp_multi_paths_vhost_single_core_performance.py b/tests/TestSuite_pvp_multi_paths_vhost_single_core_performance.py
index 6d677441..66a98911 100644
--- a/tests/TestSuite_pvp_multi_paths_vhost_single_core_performance.py
+++ b/tests/TestSuite_pvp_multi_paths_vhost_single_core_performance.py
@@ -300,7 +300,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
 
     def test_perf_vhost_single_core_virtio11_mergeable(self):
         """
-        performance for Vhost PVP virtio 1.1 Mergeable Path.
+        Case 1:performance for Vhost PVP virtio 1.1 mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -312,16 +312,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_mergeable on")
+        self.send_and_verify("virtio1.1_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_vhost_single_core_virtio11_normal(self):
+    def test_perf_vhost_single_core_virtio11_non_mergeable(self):
         """
         performance for Vhost PVP virtio1.1 Normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -333,7 +333,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1 normal")
+        self.send_and_verify("virtio1.1_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -342,7 +342,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
 
     def test_perf_vhost_single_core_virtio11_inorder_mergeable(self):
         """
-        performance for Vhost PVP virtio 1.1 inorder Mergeable Path.
+        Case 8:performance for Vhost PVP virtio 1.1 inorder mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -354,16 +354,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_inorder_mergeable on")
+        self.send_and_verify("virtio1.1_inorder_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_vhost_single_core_virtio11_inorder_normal(self):
+    def test_perf_vhost_single_core_virtio11_inorder_non_mergeable(self):
         """
         performance for Vhost PVP virtio1.1 inorder Normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -375,7 +375,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1 inorder normal")
+        self.send_and_verify("virtio1.1_inorder_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -384,7 +384,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
 
     def test_perf_vhost_single_core_virtio11_vectorized(self):
         """
-        performance for Vhost PVP virtio1.1 vectorized Path.
+        Case 10:performance for Vhost PVP virtio1.1 vectorized Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -396,7 +396,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1 inorder normal")
+        self.send_and_verify("virtio1.1_vectorized")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -405,7 +405,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
 
     def test_perf_vhost_single_core_inorder_mergeable(self):
         """
-        performance for Vhost PVP In_order mergeable Path.
+        Case 3:performance for Vhost PVP in_order mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -417,16 +417,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("inoder mergeable on")
+        self.send_and_verify("virtio1.0_inoder_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_vhost_single_core_inorder_normal(self):
+    def test_perf_vhost_single_core_inorder_non_mergeable(self):
         """
         performance for Vhost PVP In_order normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -438,7 +438,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("inoder mergeable off")
+        self.send_and_verify("virtio1.0_inoder_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -447,7 +447,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
 
     def test_perf_vhost_single_core_mergeable(self):
         """
-        performance for Vhost PVP Mergeable Path.
+        Case 5:performance for Vhost PVP mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -459,16 +459,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("mergeable on")
+        self.send_and_verify("virtio1.0_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_vhost_single_core_normal(self):
+    def test_perf_vhost_single_core_non_mergeable(self):
         """
         performance for Vhost PVP Normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -480,16 +480,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("normal")
+        self.send_and_verify("virtio1.0_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_vhost_single_core_vector_rx(self):
+    def test_perf_vhost_single_core_vectorized_rx(self):
         """
         performance for Vhost PVP Vector_RX Path
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -501,7 +501,7 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("vector rx")
+        self.send_and_verify("virtio1.0_vectorized_rx")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -312,16 +312,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP virtio1.1 Normal Path.
+        Case 2:performance for Vhost PVP virtio1.1 non-mergeable Path.
         """
         self.test_target = self.running_case
@@ -354,16 +354,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP virtio1.1 inorder Normal Path.
+        Case 9:performance for Vhost PVP virtio1.1 inorder non-mergeable Path.
         """
         self.test_target = self.running_case
@@ -417,16 +417,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP In_order normal Path.
+        Case 4:performance for Vhost PVP in_order non-mergeable Path.
         """
         self.test_target = self.running_case
@@ -459,16 +459,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP Normal Path.
+        Case 6:performance for Vhost PVP non_mergeable Path.
         """
         self.test_target = self.running_case
@@ -480,16 +480,16 @@ class TestPVPMultiPathsVhostSingleCorePerformance(TestCase):
         """
-        performance for Vhost PVP Vector_RX Path
+        Case 7:performance for Vhost PVP vectorized_rx Path
         """
         self.test_target = self.running_case
